#
#
# 3DE4.script.name:	MtoA bs_tdeLens...
#
# 3DE4.script.version:	v1.0
#
# 3DE4.script.gui:	Main Window::3DE4::Export Project
#
# 3DE4.script.comment:	Exports all the project data into a MEL script, before sourcing make sure mtoa is loaded in Maya and bs_tdeLens is installed.
#
#

#
# import sdv's python vector lib...

from vl_sdv import *

#
# functions...

def convertToAngles(r3d):
	rot	= rot3d(mat3d(r3d)).angles(VL_APPLY_ZXY)
	rx	= (rot[0]*180.0)/3.141592654
	ry	= (rot[1]*180.0)/3.141592654
	rz	= (rot[2]*180.0)/3.141592654
	return(rx,ry,rz)


def convertZup(p3d,yup):
	if yup==1:
		return(p3d)
	else:
		return([p3d[0],-p3d[2],p3d[1]])


def angleMod360(d0,d):
	dd	= d-d0
	if dd>180.0:
		d	= angleMod360(d0,d-360.0)
	else:
		if dd<-180.0:
			d	= angleMod360(d0,d+360.0)
	return d


def validName(name):
	name	= name.replace(" ","_")
	name	= name.replace("\n","")
	name	= name.replace("\r","")
	return name

def prepareImagePath(path,startframe):
	path	= path.replace("\\","/")
	i	= 0
	n	= 0
	i0	= -1
	while(i<len(path)):
		if path[i]=='#': n += 1
		if n==1: i0 = i
		i	+= 1
	if i0!=-1:
		fstring		= "%%s%%0%dd%%s"%(n)
		path2		= fstring%(path[0:i0],startframe,path[i0+n:len(path)])
		path		= path2
	return path
	

#
# main script...
		

#
# search for camera point group...

campg	= None
pgl	= tde4.getPGroupList()
for pg in pgl:
	if tde4.getPGroupType(pg)=="CAMERA": campg = pg
if campg==None:
	tde4.postQuestionRequester("Export Nothing Real bs_tdeLens MtoA...","Error, there is no camera point group.","Ok")


#
# open requester...

try:
	req	= _export_requester_maya
except (ValueError,NameError,TypeError):
	_export_requester_maya	= tde4.createCustomRequester()
	req			= _export_requester_maya
	tde4.addFileWidget(req,"file_browser","Exportfile...","*.mel")
	tde4.addTextFieldWidget(req, "startframe_field", "Startframe", "1")
	# tde4.addOptionMenuWidget(req,"mode_menu","Orientation","Y-Up", "Z-Up")
	tde4.addToggleWidget(req,"hide_ref_frames","Hide Reference Frames",0)
ret	= tde4.postCustomRequester(req,"Export Nothing Real bs_tdeLens MtoA (MEL-Script)...",600,0,"Ok","Cancel")
if ret==1:
	# yup	= tde4.getWidgetValue(req,"mode_menu")
	# if yup==2: yup = 0
	yup	= 1
	path	= tde4.getWidgetValue(req,"file_browser")
	frame0	= float(tde4.getWidgetValue(req,"startframe_field"))
	frame0	-= 1
	hide_ref= tde4.getWidgetValue(req,"hide_ref_frames")
	if path!=None:
		if not path.endswith('.mel'): path = path+'.mel' 
		f	= open(path,"w")
		if not f.closed:
			#
			# write scene group...
			
			f.write("// create scene group...\n")
			f.write("string $sceneGroupName = `group -em -name \"Scene\"`;\n")
			
			#
			# write cameras...
			
			cl	= tde4.getCameraList()
			index	= 1
			for cam in cl:
				camType		= tde4.getCameraType(cam)
				noframes	= tde4.getCameraNoFrames(cam)
				lens		= tde4.getCameraLens(cam)
				if lens!=None:
					name		= validName(tde4.getCameraName(cam))
					name		= "%s_%s_1"%(name,index)
					index		+= 1
					fback_w		= tde4.getLensFBackWidth(lens)
					fback_h		= tde4.getLensFBackHeight(lens)
					focal		= tde4.getCameraFocalLength(cam,1)
					lco_x		= tde4.getLensLensCenterX(lens)
					lco_y		= tde4.getLensLensCenterY(lens)
					
					# convert filmback to inch...
					fback_w		= fback_w/2.54
					fback_h		= fback_h/2.54
					lco_x		= -lco_x/2.54
					lco_y		= -lco_y/2.54
					
					# convert focal length to mm...
					focal		= focal*10.0
					
					# create camera...
					f.write("\n")
					f.write("// create camera %s...\n"%name)
					f.write("string $cameraNodes[] = `camera -name \"%s\" -hfa %.15f  -vfa %.15f -fl %.15f -ncp 0.01 -fcp 10000 -shutterAngle 180 -ff \"overscan\"`;\n"%(name,fback_w,fback_h,focal))					
					f.write("string $cameraTransform = $cameraNodes[0];\n")
					f.write("string $cameraShape = $cameraNodes[1];\n")
					f.write("xform -zeroTransformPivots -rotateOrder zxy $cameraTransform;\n")
					f.write("setAttr ($cameraShape+\".horizontalFilmOffset\") %.15f;\n"%lco_x);
					f.write("setAttr ($cameraShape+\".verticalFilmOffset\") %.15f;\n"%lco_y);
					p3d	= tde4.getPGroupPosition3D(campg,cam,1)
					p3d	= convertZup(p3d,yup)
					f.write("xform -translation %.15f %.15f %.15f $cameraTransform;\n"%(p3d[0],p3d[1],p3d[2]))
					r3d	= tde4.getPGroupRotation3D(campg,cam,1)
					rot	= convertToAngles(r3d)
					f.write("xform -rotation %.15f %.15f %.15f $cameraTransform;\n"%rot)
					f.write("xform -scale 1 1 1 $cameraTransform;\n")
					
					f.write("setAttr ($cameraShape + \".aiTranslator\") -type \"string\" \"bs_tdeLens\";\n")
					
					# Connecting the Common lens Paramameters to ai Equivalens
					f.write("connectAttr -f ($cameraShape + \".focalLength\") ($cameraShape + \".aiFocalLength\");\n")
					f.write("connectAttr -f ($cameraShape + \".horizontalFilmAperture\") ($cameraShape + \".aiFilmBackW\");\n")
					f.write("connectAttr -f ($cameraShape + \".verticalFilmAperture\") ($cameraShape + \".aiFilmBackH\");\n")
					f.write("connectAttr -f ($cameraShape + \".horizontalFilmOffset\") ($cameraShape + \".aiXOffset\");\n")
					f.write("connectAttr -f ($cameraShape + \".verticalFilmOffset\") ($cameraShape + \".aiYOffset\");\n")
					
					# image plane...
					f.write("\n")
					f.write("// create image plane...\n")
					f.write("string $imagePlane = `createNode imagePlane`;\n")
					f.write("cameraImagePlaneUpdate ($cameraShape, $imagePlane);\n")
					f.write("setAttr ($imagePlane + \".offsetX\") %.15f;\n"%lco_x)
					f.write("setAttr ($imagePlane + \".offsetY\") %.15f;\n"%lco_y)
					
					if camType=="SEQUENCE": f.write("setAttr ($imagePlane+\".useFrameExtension\") 1;\n")
					else:			f.write("setAttr ($imagePlane+\".useFrameExtension\") 0;\n")
					
					f.write("expression -n \"frame_ext_expression\" -s ($imagePlane+\".frameExtension=frame\");\n")
					path	= tde4.getCameraPath(cam)
					sattr	= tde4.getCameraSequenceAttr(cam)
					path	= prepareImagePath(path,sattr[0])
					f.write("setAttr ($imagePlane + \".imageName\") -type \"string\" \"%s\";\n"%(path))
					f.write("setAttr ($imagePlane + \".fit\") 4;\n")
					f.write("setAttr ($imagePlane + \".displayOnlyIfCurrent\") 1;\n")
					f.write("setAttr ($imagePlane  + \".depth\") (9000/2);\n")
					
					# parent camera to scene group...
					f.write("\n")
					f.write("// parent camera to scene group...\n")
					f.write("parent $cameraTransform $sceneGroupName;\n")
					
					if camType=="REF_FRAME" and hide_ref:
						f.write("setAttr ($cameraTransform +\".visibility\") 0;\n")
					
					# animate camera...
					if camType!="REF_FRAME":
						f.write("\n")
						f.write("// animating camera %s...\n"%name)
						f.write("playbackOptions -min %d -max %d;\n"%(1+frame0,noframes+frame0))
						f.write("\n")
					
					frame	= 1
					
					
					model = tde4.getLensLDModel(lens)

					while frame<=noframes:
						# rot/pos...
						p3d	= tde4.getPGroupPosition3D(campg,cam,frame)
						p3d	= convertZup(p3d,yup)
						r3d	= tde4.getPGroupRotation3D(campg,cam,frame)
						rot	= convertToAngles(r3d)
						if frame>1:
							rot	= [ angleMod360(rot0[0],rot[0]), angleMod360(rot0[1],rot[1]), angleMod360(rot0[2],rot[2]) ]
						rot0	= rot
						f.write("setKeyframe -at translateX -t %d -v %.15f $cameraTransform; "%(frame+frame0,p3d[0]))
						f.write("setKeyframe -at translateY -t %d -v %.15f $cameraTransform; "%(frame+frame0,p3d[1]))
						f.write("setKeyframe -at translateZ -t %d -v %.15f $cameraTransform; "%(frame+frame0,p3d[2]))
						f.write("setKeyframe -at rotateX -t %d -v %.15f $cameraTransform; "%(frame+frame0,rot[0]))
						f.write("setKeyframe -at rotateY -t %d -v %.15f $cameraTransform; "%(frame+frame0,rot[1]))
						f.write("setKeyframe -at rotateZ -t %d -v %.15f $cameraTransform; "%(frame+frame0,rot[2]))
						
						# focal length...
						F	= tde4.getCameraFocalLength(cam,frame)
						focal	= F*10.0
						f.write("setKeyframe -at focalLength -t %d -v %.15f $cameraShape;\n"%(frame+frame0,focal))
						
						# Set Distortion parameters:
						if model == '3DE Classic LD Model':
							f.write("setKeyframe -at aiModel -t %d -v %.15f $cameraShape;\n"%(frame+frame0,0))
							d  = tde4.getLensDistortion(lens,F)
							sq = tde4.getLensAnamorphSqueeze(lens,F)
							xC = tde4.getLensCurvatureX(lens,F)
							yC = tde4.getLensCurvatureY(lens,F)
							q  = tde4.getLensQuarticDistortion(lens,F)
							f.write("setKeyframe -at aiDistortion -t %d -v %.15f $cameraShape;\n"%(frame+frame0,d))
							f.write("setKeyframe -at aiAnamorphicSqueeze -t %d -v %.15f $cameraShape;\n"%(frame+frame0,sq))
							f.write("setKeyframe -at aiXCurvature -t %d -v %.15f $cameraShape;\n"%(frame+frame0,xC))
							f.write("setKeyframe -at aiYCurvature -t %d -v %.15f $cameraShape;\n"%(frame+frame0,yC))
							f.write("setKeyframe -at aiQuarticDist -t %d -v %.15f $cameraShape;\n"%(frame+frame0,q))
						
						if model == '3DE4 Radial - Standard, Degree 4':
							f.write("setKeyframe -at aiModel -t %d -v %.15f $cameraShape;\n"%(frame+frame0,1))
							dd2 = tde4.getLensLDAdjustableParameter(lens, "Distortion - Degree 2", F)
							ud2 = tde4.getLensLDAdjustableParameter(lens, "U - Degree 2", F)
							vd2 = tde4.getLensLDAdjustableParameter(lens, "V - Degree 2", F)
							qd4 = tde4.getLensLDAdjustableParameter(lens, "Quartic Distortion - Degree 4", F)
							ud4 = tde4.getLensLDAdjustableParameter(lens, "U - Degree 4", F)
							vd4 = tde4.getLensLDAdjustableParameter(lens, "V - Degree 4", F)
							f.write("setKeyframe -at aiDistortionDegree2 -t %d -v %.15f $cameraShape;\n"%(frame+frame0,dd2))
							f.write("setKeyframe -at aiUDegree2 -t %d -v %.15f $cameraShape;\n"%(frame+frame0,ud2))
							f.write("setKeyframe -at aiVDegree2 -t %d -v %.15f $cameraShape;\n"%(frame+frame0,vd2))
							f.write("setKeyframe -at aiQuarticDegree4 -t %d -v %.15f $cameraShape;\n"%(frame+frame0,qd4))
							f.write("setKeyframe -at aiUDegree4 -t %d -v %.15f $cameraShape;\n"%(frame+frame0,ud4))
							f.write("setKeyframe -at aiVDegree4 -t %d -v %.15f $cameraShape;\n"%(frame+frame0,vd4))
						
						if model == '3DE4 Radial - Fisheye, Degree 8':
							f.write("setKeyframe -at aiModel -t %d -v %.15f $cameraShape;\n"%(frame+frame0,2))
							dd2 = tde4.getLensLDAdjustableParameter(lens, "Distortion - Degree 2", F)
							qd4 = tde4.getLensLDAdjustableParameter(lens, "Quartic Distortion - Degree 4", F)
							d6 = tde4.getLensLDAdjustableParameter(lens, "Degree 6", F)
							d8 = tde4.getLensLDAdjustableParameter(lens, "Degree 8", F)
							f.write("setKeyframe -at aiDistortionDegree2 -t %d -v %.15f $cameraShape;\n"%(frame+frame0,dd2))
							f.write("setKeyframe -at aiQuarticDegree4 -t %d -v %.15f $cameraShape;\n"%(frame+frame0,qd4))
							f.write("setKeyframe -at aiDegree6 -t %d -v %.15f $cameraShape;\n"%(frame+frame0,d6))
							f.write("setKeyframe -at aiDegree8 -t %d -v %.15f $cameraShape;\n"%(frame+frame0,d8))
							
						if model == '3DE4 Anamorphic, Degree 6':
							f.write("setKeyframe -at aiModel -t %d -v %.15f $cameraShape;\n"%(frame+frame0,3))
							cx02d2 = tde4.getLensLDAdjustableParameter(lens, "Cx02 - Degree 2", F)
							cy02d2 = tde4.getLensLDAdjustableParameter(lens, "Cy02 - Degree 2", F)
							cx22d2 = tde4.getLensLDAdjustableParameter(lens, "Cx22 - Degree 2", F)
							cy22d2 = tde4.getLensLDAdjustableParameter(lens, "Cy22 - Degree 2", F)
							cx04d4 = tde4.getLensLDAdjustableParameter(lens, "Cx04 - Degree 4", F)
							cy04d4 = tde4.getLensLDAdjustableParameter(lens, "Cy04 - Degree 4", F)
							cx24d4 = tde4.getLensLDAdjustableParameter(lens, "Cx24 - Degree 4", F)
							cy24d4 = tde4.getLensLDAdjustableParameter(lens, "Cy24 - Degree 4", F)
							cx44d4 = tde4.getLensLDAdjustableParameter(lens, "Cx44 - Degree 4", F)
							cy44d4 = tde4.getLensLDAdjustableParameter(lens, "Cy44 - Degree 4", F)
							cx06d6 = tde4.getLensLDAdjustableParameter(lens, "Cx06 - Degree 6", F)
							cy06d6 = tde4.getLensLDAdjustableParameter(lens, "Cy06 - Degree 6", F)
							cx26d6 = tde4.getLensLDAdjustableParameter(lens, "Cx26 - Degree 6", F)
							cy26d6 = tde4.getLensLDAdjustableParameter(lens, "Cy26 - Degree 6", F)
							cx46d6 = tde4.getLensLDAdjustableParameter(lens, "Cx46 - Degree 6", F)
							cy46d6 = tde4.getLensLDAdjustableParameter(lens, "Cy46 - Degree 6", F)
							cx66d6 = tde4.getLensLDAdjustableParameter(lens, "Cx66 - Degree 6", F)
							cy66d6 = tde4.getLensLDAdjustableParameter(lens, "Cy66 - Degree 6", F)
							
							f.write("setKeyframe -at aiCx02d2 -t %d -v %.15f $cameraShape;\n"%(frame+frame0,cx02d2))
							f.write("setKeyframe -at aiCy02d2 -t %d -v %.15f $cameraShape;\n"%(frame+frame0,cy02d2))
							f.write("setKeyframe -at aiCx22d2 -t %d -v %.15f $cameraShape;\n"%(frame+frame0,cx22d2))
							f.write("setKeyframe -at aiCy22d2 -t %d -v %.15f $cameraShape;\n"%(frame+frame0,cy22d2))
							f.write("setKeyframe -at aiCx04d4 -t %d -v %.15f $cameraShape;\n"%(frame+frame0,cx04d4))
							f.write("setKeyframe -at aiCy04d4 -t %d -v %.15f $cameraShape;\n"%(frame+frame0,cy04d4))
							f.write("setKeyframe -at aiCx24d4 -t %d -v %.15f $cameraShape;\n"%(frame+frame0,cx24d4))
							f.write("setKeyframe -at aiCy24d4 -t %d -v %.15f $cameraShape;\n"%(frame+frame0,cy24d4))
							f.write("setKeyframe -at aiCx44d4 -t %d -v %.15f $cameraShape;\n"%(frame+frame0,cx44d4))
							f.write("setKeyframe -at aiCy44d4 -t %d -v %.15f $cameraShape;\n"%(frame+frame0,cy44d4))
							f.write("setKeyframe -at aiCx06d6 -t %d -v %.15f $cameraShape;\n"%(frame+frame0,cx06d6))
							f.write("setKeyframe -at aiCy06d6 -t %d -v %.15f $cameraShape;\n"%(frame+frame0,cy06d6))
							f.write("setKeyframe -at aiCx26d6 -t %d -v %.15f $cameraShape;\n"%(frame+frame0,cx26d6))
							f.write("setKeyframe -at aiCy26d6 -t %d -v %.15f $cameraShape;\n"%(frame+frame0,cy26d6))
							f.write("setKeyframe -at aiCx46d6 -t %d -v %.15f $cameraShape;\n"%(frame+frame0,cx46d6))
							f.write("setKeyframe -at aiCy46d6 -t %d -v %.15f $cameraShape;\n"%(frame+frame0,cy46d6))
							f.write("setKeyframe -at aiCx66d6 -t %d -v %.15f $cameraShape;\n"%(frame+frame0,cx66d6))
							f.write("setKeyframe -at aiCy66d6 -t %d -v %.15f $cameraShape;\n"%(frame+frame0,cy66d6))

						frame	+= 1
					
			#
			# write camera point group...
			
			f.write("\n")
			f.write("// create camera point group...\n")
			name	= "cameraPGroup_%s_1"%validName(tde4.getPGroupName(campg))
			f.write("string $pointGroupName = `group -em -name  \"%s\" -parent $sceneGroupName`;\n"%name)
			f.write("$pointGroupName = ($sceneGroupName + \"|\" + $pointGroupName);\n")
			f.write("\n")
			
			# write points...
			l	= tde4.getPointList(campg)
			for p in l:
				if tde4.isPointCalculated3D(campg,p):
					name	= tde4.getPointName(campg,p)
					name	= "p%s"%validName(name)
					p3d	= tde4.getPointCalcPosition3D(campg,p)
					p3d	= convertZup(p3d,yup)
					f.write("\n")
					f.write("// create point %s...\n"%name)
					f.write("string $locator = stringArrayToString(`spaceLocator -name %s`, \"\");\n"%name)
					f.write("$locator = (\"|\" + $locator);\n")
					f.write("xform -t %.15f %.15f %.15f $locator;\n"%(p3d[0],p3d[1],p3d[2]))
					f.write("parent $locator $pointGroupName;\n")
			
			f.write("\n")
			f.write("xform -zeroTransformPivots -rotateOrder zxy -scale 1.000000 1.000000 1.000000 $pointGroupName;\n")
			f.write("\n")
			
			
			#
			# write object/mocap point groups...
			
			camera		= tde4.getCurrentCamera()
			noframes	= tde4.getCameraNoFrames(camera)
			pgl		= tde4.getPGroupList()
			index		= 1
			for pg in pgl:
				if tde4.getPGroupType(pg)=="OBJECT" and camera!=None:
					f.write("\n")
					f.write("// create object point group...\n")
					pgname	= "objectPGroup_%s_%d_1"%(validName(tde4.getPGroupName(pg)),index)
					index	+= 1
					f.write("string $pointGroupName = `group -em -name  \"%s\" -parent $sceneGroupName`;\n"%pgname)
					f.write("$pointGroupName = ($sceneGroupName + \"|\" + $pointGroupName);\n")
					
					# write points...
					l	= tde4.getPointList(pg)
					for p in l:
						if tde4.isPointCalculated3D(pg,p):
							name	= tde4.getPointName(pg,p)
							name	= "p%s"%validName(name)
							p3d	= tde4.getPointCalcPosition3D(pg,p)
							p3d	= convertZup(p3d,yup)
							f.write("\n")
							f.write("// create point %s...\n"%name)
							f.write("string $locator = stringArrayToString(`spaceLocator -name %s`, \"\");\n"%name)
							f.write("$locator = (\"|\" + $locator);\n")
							f.write("xform -t %.15f %.15f %.15f $locator;\n"%(p3d[0],p3d[1],p3d[2]))
							f.write("parent $locator $pointGroupName;\n")
					
					f.write("\n")
					scale	= tde4.getPGroupScale3D(pg)
					f.write("xform -zeroTransformPivots -rotateOrder zxy -scale %.15f %.15f %.15f $pointGroupName;\n"%(scale,scale,scale))

					# animate object point group...
					f.write("\n")
					f.write("// animating point group %s...\n"%pgname)
					frame	= 1
					while frame<=noframes:
						# rot/pos...
						p3d	= tde4.getPGroupPosition3D(pg,camera,frame)
						p3d	= convertZup(p3d,yup)
						r3d	= tde4.getPGroupRotation3D(pg,camera,frame)
						rot	= convertToAngles(r3d)
						if frame>1:
							rot	= [ angleMod360(rot0[0],rot[0]), angleMod360(rot0[1],rot[1]), angleMod360(rot0[2],rot[2]) ]
						rot0	= rot
						f.write("setKeyframe -at translateX -t %d -v %.15f $pointGroupName; "%(frame+frame0,p3d[0]))
						f.write("setKeyframe -at translateY -t %d -v %.15f $pointGroupName; "%(frame+frame0,p3d[1]))
						f.write("setKeyframe -at translateZ -t %d -v %.15f $pointGroupName; "%(frame+frame0,p3d[2]))
						f.write("setKeyframe -at rotateX -t %d -v %.15f $pointGroupName; "%(frame+frame0,rot[0]))
						f.write("setKeyframe -at rotateY -t %d -v %.15f $pointGroupName; "%(frame+frame0,rot[1]))
						f.write("setKeyframe -at rotateZ -t %d -v %.15f $pointGroupName;\n"%(frame+frame0,rot[2]))
						
						frame	+= 1
				
				# mocap point groups...
				if tde4.getPGroupType(pg)=="MOCAP" and camera!=None:
					f.write("\n")
					f.write("// create mocap point group...\n")
					pgname	= "objectPGroup_%s_%d_1"%(validName(tde4.getPGroupName(pg)),index)
					index	+= 1
					f.write("string $pointGroupName = `group -em -name  \"%s\" -parent $sceneGroupName`;\n"%pgname)
					f.write("$pointGroupName = ($sceneGroupName + \"|\" + $pointGroupName);\n")
					
					# write points...
					l	= tde4.getPointList(pg)
					for p in l:
						if tde4.isPointCalculated3D(pg,p):
							name	= tde4.getPointName(pg,p)
							name	= "p%s"%validName(name)
							p3d	= tde4.getPointMoCapCalcPosition3D(pg,p,camera,1)
							p3d	= convertZup(p3d,yup)
							f.write("\n")
							f.write("// create point %s...\n"%name)
							f.write("string $locator = stringArrayToString(`spaceLocator -name %s`, \"\");\n"%name)
							f.write("$locator = (\"|\" + $locator);\n")
							f.write("xform -t %.15f %.15f %.15f $locator;\n"%(p3d[0],p3d[1],p3d[2]))
							for frame in range(1,noframes+1):
								p3d	= tde4.getPointMoCapCalcPosition3D(pg,p,camera,frame)
								p3d	= convertZup(p3d,yup)
								f.write("setKeyframe -at translateX -t %d -v %.15f $locator; "%(frame+frame0,p3d[0]))
								f.write("setKeyframe -at translateY -t %d -v %.15f $locator; "%(frame+frame0,p3d[1]))
								f.write("setKeyframe -at translateZ -t %d -v %.15f $locator; "%(frame+frame0,p3d[2]))
							f.write("parent $locator $pointGroupName;\n")
					
					f.write("\n")
					scale	= tde4.getPGroupScale3D(pg)
					f.write("xform -zeroTransformPivots -rotateOrder zxy -scale %.15f %.15f %.15f $pointGroupName;\n"%(scale,scale,scale))

					# animate mocap point group...
					f.write("\n")
					f.write("// animating point group %s...\n"%pgname)
					frame	= 1
					while frame<=noframes:
						# rot/pos...
						p3d	= tde4.getPGroupPosition3D(pg,camera,frame)
						p3d	= convertZup(p3d,yup)
						r3d	= tde4.getPGroupRotation3D(pg,camera,frame)
						rot	= convertToAngles(r3d)
						if frame>1:
							rot	= [ angleMod360(rot0[0],rot[0]), angleMod360(rot0[1],rot[1]), angleMod360(rot0[2],rot[2]) ]
						rot0	= rot
						f.write("setKeyframe -at translateX -t %d -v %.15f $pointGroupName; "%(frame+frame0,p3d[0]))
						f.write("setKeyframe -at translateY -t %d -v %.15f $pointGroupName; "%(frame+frame0,p3d[1]))
						f.write("setKeyframe -at translateZ -t %d -v %.15f $pointGroupName; "%(frame+frame0,p3d[2]))
						f.write("setKeyframe -at rotateX -t %d -v %.15f $pointGroupName; "%(frame+frame0,rot[0]))
						f.write("setKeyframe -at rotateY -t %d -v %.15f $pointGroupName; "%(frame+frame0,rot[1]))
						f.write("setKeyframe -at rotateZ -t %d -v %.15f $pointGroupName;\n"%(frame+frame0,rot[2]))
						
						frame	+= 1
			
			
			#
			# global (scene node) transformation...
			
			p3d	= tde4.getScenePosition3D()
			p3d	= convertZup(p3d,yup)
			r3d	= tde4.getSceneRotation3D()
			rot	= convertToAngles(r3d)
			s	= tde4.getSceneScale3D()
			f.write("xform -zeroTransformPivots -rotateOrder zxy -translation %.15f %.15f %.15f -scale %.15f %.15f %.15f -rotation %.15f %.15f %.15f $sceneGroupName;\n\n"%(p3d[0],p3d[1],p3d[2],s,s,s,rot[0],rot[1],rot[2]))
			
			f.write("\n")
			f.close()
			
			tde4.postQuestionRequester("Export Nothing Real bs_tdeLens MtoA...","Project successfully exported.\nPlease, make sure to load the 'mtoa' plugin in Maya before sourcing the Mel script.","Ok")
		else:
			tde4.postQuestionRequester("Export Nothing Real bs_tdeLens MtoA...","Error, couldn't open file.","Ok")


